/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */
/* THIS FILE IS AUTOGENERATED! */
#ifndef __ATOMICS_SKEL_H__
#define __ATOMICS_SKEL_H__

#include <stdlib.h>
#include <bpf/bpf.h>
#include <bpf/skel_internal.h>

struct atomics {
	struct bpf_loader_ctx ctx;
	struct {
		struct bpf_map_desc data;
		struct bpf_map_desc bss;
	} maps;
	struct {
		struct bpf_prog_desc add;
		struct bpf_prog_desc sub;
		struct bpf_prog_desc and;
		struct bpf_prog_desc or;
		struct bpf_prog_desc xor;
		struct bpf_prog_desc cmpxchg;
		struct bpf_prog_desc xchg;
	} progs;
	struct {
		int add_fd;
		int sub_fd;
		int and_fd;
		int or_fd;
		int xor_fd;
		int cmpxchg_fd;
		int xchg_fd;
	} links;
	struct atomics__data {
		_Bool skip_tests;
		char __pad0[7];
		__u64 add64_value;
		__u32 add32_value;
		char __pad1[4];
		__u64 add_noreturn_value;
		__s64 sub64_value;
		__s32 sub32_value;
		char __pad2[4];
		__s64 sub_noreturn_value;
		__u64 and64_value;
		__u32 and32_value;
		char __pad3[4];
		__u64 and_noreturn_value;
		__u64 or64_value;
		__u32 or32_value;
		char __pad4[4];
		__u64 or_noreturn_value;
		__u64 xor64_value;
		__u32 xor32_value;
		char __pad5[4];
		__u64 xor_noreturn_value;
		__u64 cmpxchg64_value;
		__u32 cmpxchg32_value;
		char __pad6[4];
		__u64 xchg64_value;
		__u32 xchg32_value;
	} *data;
	struct atomics__bss {
		__u64 add64_result;
		__u32 add32_result;
		char __pad0[4];
		__u64 add_stack_value_copy;
		__u64 add_stack_result;
		__s64 sub64_result;
		__s32 sub32_result;
		char __pad1[4];
		__s64 sub_stack_value_copy;
		__s64 sub_stack_result;
		__u64 and64_result;
		__u32 and32_result;
		char __pad2[4];
		__u64 or64_result;
		__u32 or32_result;
		char __pad3[4];
		__u64 xor64_result;
		__u32 xor32_result;
		char __pad4[4];
		__u64 cmpxchg64_result_fail;
		__u64 cmpxchg64_result_succeed;
		__u32 cmpxchg32_result_fail;
		__u32 cmpxchg32_result_succeed;
		__u64 xchg64_result;
		__u32 xchg32_result;
	} *bss;
};

static inline int
atomics__add__attach(struct atomics *skel)
{
	int prog_fd = skel->progs.add.prog_fd;
	int fd = bpf_raw_tracepoint_open(NULL, prog_fd);

	if (fd > 0)
		skel->links.add_fd = fd;
	return fd;
}

static inline int
atomics__sub__attach(struct atomics *skel)
{
	int prog_fd = skel->progs.sub.prog_fd;
	int fd = bpf_raw_tracepoint_open(NULL, prog_fd);

	if (fd > 0)
		skel->links.sub_fd = fd;
	return fd;
}

static inline int
atomics__and__attach(struct atomics *skel)
{
	int prog_fd = skel->progs.and.prog_fd;
	int fd = bpf_raw_tracepoint_open(NULL, prog_fd);

	if (fd > 0)
		skel->links.and_fd = fd;
	return fd;
}

static inline int
atomics__or__attach(struct atomics *skel)
{
	int prog_fd = skel->progs.or.prog_fd;
	int fd = bpf_raw_tracepoint_open(NULL, prog_fd);

	if (fd > 0)
		skel->links.or_fd = fd;
	return fd;
}

static inline int
atomics__xor__attach(struct atomics *skel)
{
	int prog_fd = skel->progs.xor.prog_fd;
	int fd = bpf_raw_tracepoint_open(NULL, prog_fd);

	if (fd > 0)
		skel->links.xor_fd = fd;
	return fd;
}

static inline int
atomics__cmpxchg__attach(struct atomics *skel)
{
	int prog_fd = skel->progs.cmpxchg.prog_fd;
	int fd = bpf_raw_tracepoint_open(NULL, prog_fd);

	if (fd > 0)
		skel->links.cmpxchg_fd = fd;
	return fd;
}

static inline int
atomics__xchg__attach(struct atomics *skel)
{
	int prog_fd = skel->progs.xchg.prog_fd;
	int fd = bpf_raw_tracepoint_open(NULL, prog_fd);

	if (fd > 0)
		skel->links.xchg_fd = fd;
	return fd;
}

static inline int
atomics__attach(struct atomics *skel)
{
	int ret = 0;

	ret = ret < 0 ? ret : atomics__add__attach(skel);
	ret = ret < 0 ? ret : atomics__sub__attach(skel);
	ret = ret < 0 ? ret : atomics__and__attach(skel);
	ret = ret < 0 ? ret : atomics__or__attach(skel);
	ret = ret < 0 ? ret : atomics__xor__attach(skel);
	ret = ret < 0 ? ret : atomics__cmpxchg__attach(skel);
	ret = ret < 0 ? ret : atomics__xchg__attach(skel);
	return ret < 0 ? ret : 0;
}

static inline void
atomics__detach(struct atomics *skel)
{
	skel_closenz(skel->links.add_fd);
	skel_closenz(skel->links.sub_fd);
	skel_closenz(skel->links.and_fd);
	skel_closenz(skel->links.or_fd);
	skel_closenz(skel->links.xor_fd);
	skel_closenz(skel->links.cmpxchg_fd);
	skel_closenz(skel->links.xchg_fd);
}
static void
atomics__destroy(struct atomics *skel)
{
	if (!skel)
		return;
	atomics__detach(skel);
	skel_closenz(skel->progs.add.prog_fd);
	skel_closenz(skel->progs.sub.prog_fd);
	skel_closenz(skel->progs.and.prog_fd);
	skel_closenz(skel->progs.or.prog_fd);
	skel_closenz(skel->progs.xor.prog_fd);
	skel_closenz(skel->progs.cmpxchg.prog_fd);
	skel_closenz(skel->progs.xchg.prog_fd);
	munmap(skel->data, 4096);
	skel_closenz(skel->maps.data.map_fd);
	munmap(skel->bss, 4096);
	skel_closenz(skel->maps.bss.map_fd);
	free(skel);
}
static inline struct atomics *
atomics__open(void)
{
	struct atomics *skel;

	skel = calloc(sizeof(*skel), 1);
	if (!skel)
		goto cleanup;
	skel->ctx.sz = (void *)&skel->links - (void *)skel;
	skel->data =
		mmap(NULL, 4096, PROT_READ | PROT_WRITE,
		     MAP_SHARED | MAP_ANONYMOUS, -1, 0);
	if (skel->data == (void *) -1)
		goto cleanup;
	memcpy(skel->data, (void *)"\
\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\
\0\0\0\0\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\x01\x10\0\0\0\0\0\0\x01\
\x10\0\0\0\0\0\0\x01\x10\0\0\0\0\0\0\x01\x10\0\0\0\0\0\0\x01\x10\0\0\0\0\0\0\
\x01\x10\0\0\0\0\0\0\x01\x10\0\0\0\0\0\0\x01\x10\0\0\0\0\0\0\x01\x10\0\0\0\0\0\
\0\0\0\0\0\0\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x01", 156);
	skel->maps.data.initial_value = (__u64)(long)skel->data;
	skel->bss =
		mmap(NULL, 4096, PROT_READ | PROT_WRITE,
		     MAP_SHARED | MAP_ANONYMOUS, -1, 0);
	if (skel->bss == (void *) -1)
		goto cleanup;
	memcpy(skel->bss, (void *)"\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0", 148);
	skel->maps.bss.initial_value = (__u64)(long)skel->bss;
	return skel;
cleanup:
	atomics__destroy(skel);
	return NULL;
}

static inline int
atomics__load(struct atomics *skel)
{
	struct bpf_load_and_run_opts opts = {};
	int err;

	opts.ctx = (struct bpf_loader_ctx *)skel;
	opts.data_sz = 4311;
	opts.data = (void *)"\
\xeb\x9f\x01\0\0\0\0\x18\0\0\0\0\0\0\x05\x6c\0\0\x05\x6c\0\0\x04\x29\0\0\0\0\
\x02\0\0\0\0\0\0\x02\0\0\0\x01\x01\0\0\0\0\0\0\x08\0\0\0\x40\0\0\0\0\x0d\0\0\
\x01\0\0\0\x04\0\0\0\x18\0\0\0\x01\0\0\0\x1c\x01\0\0\0\0\0\0\x04\x01\0\0\x20\0\
\0\0\x20\x0c\0\0\x01\0\0\0\x03\0\0\0\x24\x0c\0\0\x01\0\0\0\x03\0\0\0\x28\x0c\0\
\0\x01\0\0\0\x03\0\0\0\x2c\x0c\0\0\x01\0\0\0\x03\0\0\0\x2f\x0c\0\0\x01\0\0\0\
\x03\0\0\0\x33\x0c\0\0\x01\0\0\0\x03\0\0\0\x3b\x0c\0\0\x01\0\0\0\x03\0\0\0\x40\
\x01\0\0\0\0\0\0\x01\x04\0\0\x08\0\0\0\x46\x0e\0\0\0\0\0\0\x0c\0\0\0\x01\0\0\0\
\x51\x08\0\0\0\0\0\0\x02\0\0\0\x57\x0e\0\0\0\0\0\0\x0e\0\0\0\x01\0\0\0\x63\x0e\
\0\0\0\0\0\0\x0e\0\0\0\x01\0\0\0\x70\x08\0\0\0\0\0\0\x12\0\0\0\x76\x01\0\0\0\0\
\0\0\x04\0\0\0\x20\0\0\0\x83\x0e\0\0\0\0\0\0\x11\0\0\0\x01\0\0\0\x8f\x0e\0\0\0\
\0\0\0\x11\0\0\0\x01\0\0\0\x9c\x0e\0\0\0\0\0\0\x0e\0\0\0\x01\0\0\0\xb1\x0e\0\0\
\0\0\0\0\x0e\0\0\0\x01\0\0\0\xc2\x0e\0\0\0\0\0\0\x0e\0\0\0\x01\0\0\0\xd5\x08\0\
\0\0\0\0\0\x19\0\0\0\xdb\x01\0\0\0\0\0\0\x08\x01\0\0\x40\0\0\0\xe9\x0e\0\0\0\0\
\0\0\x18\0\0\0\x01\0\0\0\xf5\x0e\0\0\0\0\0\0\x18\0\0\0\x01\0\0\x01\x02\x08\0\0\
\0\0\0\0\x04\0\0\x01\x08\x0e\0\0\0\0\0\0\x1c\0\0\0\x01\0\0\x01\x14\x0e\0\0\0\0\
\0\0\x1c\0\0\0\x01\0\0\x01\x21\x0e\0\0\0\0\0\0\x18\0\0\0\x01\0\0\x01\x36\x0e\0\
\0\0\0\0\0\x18\0\0\0\x01\0\0\x01\x47\x0e\0\0\0\0\0\0\x18\0\0\0\x01\0\0\x01\x5a\
\x0e\0\0\0\0\0\0\x0e\0\0\0\x01\0\0\x01\x66\x0e\0\0\0\0\0\0\x0e\0\0\0\x01\0\0\
\x01\x73\x0e\0\0\0\0\0\0\x11\0\0\0\x01\0\0\x01\x7f\x0e\0\0\0\0\0\0\x11\0\0\0\
\x01\0\0\x01\x8c\x0e\0\0\0\0\0\0\x0e\0\0\0\x01\0\0\x01\x9f\x0e\0\0\0\0\0\0\x0e\
\0\0\0\x01\0\0\x01\xaa\x0e\0\0\0\0\0\0\x0e\0\0\0\x01\0\0\x01\xb6\x0e\0\0\0\0\0\
\0\x11\0\0\0\x01\0\0\x01\xc1\x0e\0\0\0\0\0\0\x11\0\0\0\x01\0\0\x01\xcd\x0e\0\0\
\0\0\0\0\x0e\0\0\0\x01\0\0\x01\xdf\x0e\0\0\0\0\0\0\x0e\0\0\0\x01\0\0\x01\xeb\
\x0e\0\0\0\0\0\0\x0e\0\0\0\x01\0\0\x01\xf8\x0e\0\0\0\0\0\0\x11\0\0\0\x01\0\0\
\x02\x04\x0e\0\0\0\0\0\0\x11\0\0\0\x01\0\0\x02\x11\x0e\0\0\0\0\0\0\x0e\0\0\0\
\x01\0\0\x02\x24\x0e\0\0\0\0\0\0\x0e\0\0\0\x01\0\0\x02\x34\x0e\0\0\0\0\0\0\x0e\
\0\0\0\x01\0\0\x02\x4a\x0e\0\0\0\0\0\0\x0e\0\0\0\x01\0\0\x02\x63\x0e\0\0\0\0\0\
\0\x11\0\0\0\x01\0\0\x02\x73\x0e\0\0\0\0\0\0\x11\0\0\0\x01\0\0\x02\x89\x0e\0\0\
\0\0\0\0\x11\0\0\0\x01\0\0\x02\xa2\x0e\0\0\0\0\0\0\x0e\0\0\0\x01\0\0\x02\xaf\
\x0e\0\0\0\0\0\0\x0e\0\0\0\x01\0\0\x02\xbd\x0e\0\0\0\0\0\0\x11\0\0\0\x01\0\0\
\x02\xca\x0e\0\0\0\0\0\0\x11\0\0\0\x01\0\0\x04\x06\x0f\0\0\x14\0\0\0\x9c\0\0\0\
\x0d\0\0\0\0\0\0\0\x01\0\0\0\x0f\0\0\0\x08\0\0\0\x08\0\0\0\x13\0\0\0\x10\0\0\0\
\x04\0\0\0\x17\0\0\0\x18\0\0\0\x08\0\0\0\x1a\0\0\0\x20\0\0\0\x08\0\0\0\x1d\0\0\
\0\x28\0\0\0\x04\0\0\0\x21\0\0\0\x30\0\0\0\x08\0\0\0\x22\0\0\0\x38\0\0\0\x08\0\
\0\0\x24\0\0\0\x40\0\0\0\x04\0\0\0\x26\0\0\0\x48\0\0\0\x08\0\0\0\x27\0\0\0\x50\
\0\0\0\x08\0\0\0\x29\0\0\0\x58\0\0\0\x04\0\0\0\x2b\0\0\0\x60\0\0\0\x08\0\0\0\
\x2c\0\0\0\x68\0\0\0\x08\0\0\0\x2e\0\0\0\x70\0\0\0\x04\0\0\0\x30\0\0\0\x78\0\0\
\0\x08\0\0\0\x31\0\0\0\x80\0\0\0\x08\0\0\0\x34\0\0\0\x88\0\0\0\x04\0\0\0\x37\0\
\0\0\x90\0\0\0\x08\0\0\0\x39\0\0\0\x98\0\0\0\x04\0\0\x04\x0c\x0f\0\0\x14\0\0\0\
\x94\0\0\0\x10\0\0\0\0\0\0\0\x08\0\0\0\x14\0\0\0\x08\0\0\0\x04\0\0\0\x15\0\0\0\
\x10\0\0\0\x08\0\0\0\x16\0\0\0\x18\0\0\0\x08\0\0\0\x1b\0\0\0\x20\0\0\0\x08\0\0\
\0\x1e\0\0\0\x28\0\0\0\x04\0\0\0\x1f\0\0\0\x30\0\0\0\x08\0\0\0\x20\0\0\0\x38\0\
\0\0\x08\0\0\0\x23\0\0\0\x40\0\0\0\x08\0\0\0\x25\0\0\0\x48\0\0\0\x04\0\0\0\x28\
\0\0\0\x50\0\0\0\x08\0\0\0\x2a\0\0\0\x58\0\0\0\x04\0\0\0\x2d\0\0\0\x60\0\0\0\
\x08\0\0\0\x2f\0\0\0\x68\0\0\0\x04\0\0\0\x32\0\0\0\x70\0\0\0\x08\0\0\0\x33\0\0\
\0\x78\0\0\0\x08\0\0\0\x35\0\0\0\x80\0\0\0\x04\0\0\0\x36\0\0\0\x84\0\0\0\x04\0\
\0\0\x38\0\0\0\x88\0\0\0\x08\0\0\0\x3a\0\0\0\x90\0\0\0\x04\0\x6c\x6f\x6e\x67\
\x20\x6c\x6f\x6e\x67\x20\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x63\
\x74\x78\0\x69\x6e\x74\0\x61\x64\x64\0\x73\x75\x62\0\x61\x6e\x64\0\x6f\x72\0\
\x78\x6f\x72\0\x63\x6d\x70\x78\x63\x68\x67\0\x78\x63\x68\x67\0\x5f\x42\x6f\x6f\
\x6c\0\x73\x6b\x69\x70\x5f\x74\x65\x73\x74\x73\0\x5f\x5f\x75\x36\x34\0\x61\x64\
\x64\x36\x34\x5f\x76\x61\x6c\x75\x65\0\x61\x64\x64\x36\x34\x5f\x72\x65\x73\x75\
\x6c\x74\0\x5f\x5f\x75\x33\x32\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\
\x74\0\x61\x64\x64\x33\x32\x5f\x76\x61\x6c\x75\x65\0\x61\x64\x64\x33\x32\x5f\
\x72\x65\x73\x75\x6c\x74\0\x61\x64\x64\x5f\x73\x74\x61\x63\x6b\x5f\x76\x61\x6c\
\x75\x65\x5f\x63\x6f\x70\x79\0\x61\x64\x64\x5f\x73\x74\x61\x63\x6b\x5f\x72\x65\
\x73\x75\x6c\x74\0\x61\x64\x64\x5f\x6e\x6f\x72\x65\x74\x75\x72\x6e\x5f\x76\x61\
\x6c\x75\x65\0\x5f\x5f\x73\x36\x34\0\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\x20\
\x69\x6e\x74\0\x73\x75\x62\x36\x34\x5f\x76\x61\x6c\x75\x65\0\x73\x75\x62\x36\
\x34\x5f\x72\x65\x73\x75\x6c\x74\0\x5f\x5f\x73\x33\x32\0\x73\x75\x62\x33\x32\
\x5f\x76\x61\x6c\x75\x65\0\x73\x75\x62\x33\x32\x5f\x72\x65\x73\x75\x6c\x74\0\
\x73\x75\x62\x5f\x73\x74\x61\x63\x6b\x5f\x76\x61\x6c\x75\x65\x5f\x63\x6f\x70\
\x79\0\x73\x75\x62\x5f\x73\x74\x61\x63\x6b\x5f\x72\x65\x73\x75\x6c\x74\0\x73\
\x75\x62\x5f\x6e\x6f\x72\x65\x74\x75\x72\x6e\x5f\x76\x61\x6c\x75\x65\0\x61\x6e\
\x64\x36\x34\x5f\x76\x61\x6c\x75\x65\0\x61\x6e\x64\x36\x34\x5f\x72\x65\x73\x75\
\x6c\x74\0\x61\x6e\x64\x33\x32\x5f\x76\x61\x6c\x75\x65\0\x61\x6e\x64\x33\x32\
\x5f\x72\x65\x73\x75\x6c\x74\0\x61\x6e\x64\x5f\x6e\x6f\x72\x65\x74\x75\x72\x6e\
\x5f\x76\x61\x6c\x75\x65\0\x6f\x72\x36\x34\x5f\x76\x61\x6c\x75\x65\0\x6f\x72\
\x36\x34\x5f\x72\x65\x73\x75\x6c\x74\0\x6f\x72\x33\x32\x5f\x76\x61\x6c\x75\x65\
\0\x6f\x72\x33\x32\x5f\x72\x65\x73\x75\x6c\x74\0\x6f\x72\x5f\x6e\x6f\x72\x65\
\x74\x75\x72\x6e\x5f\x76\x61\x6c\x75\x65\0\x78\x6f\x72\x36\x34\x5f\x76\x61\x6c\
\x75\x65\0\x78\x6f\x72\x36\x34\x5f\x72\x65\x73\x75\x6c\x74\0\x78\x6f\x72\x33\
\x32\x5f\x76\x61\x6c\x75\x65\0\x78\x6f\x72\x33\x32\x5f\x72\x65\x73\x75\x6c\x74\
\0\x78\x6f\x72\x5f\x6e\x6f\x72\x65\x74\x75\x72\x6e\x5f\x76\x61\x6c\x75\x65\0\
\x63\x6d\x70\x78\x63\x68\x67\x36\x34\x5f\x76\x61\x6c\x75\x65\0\x63\x6d\x70\x78\
\x63\x68\x67\x36\x34\x5f\x72\x65\x73\x75\x6c\x74\x5f\x66\x61\x69\x6c\0\x63\x6d\
\x70\x78\x63\x68\x67\x36\x34\x5f\x72\x65\x73\x75\x6c\x74\x5f\x73\x75\x63\x63\
\x65\x65\x64\0\x63\x6d\x70\x78\x63\x68\x67\x33\x32\x5f\x76\x61\x6c\x75\x65\0\
\x63\x6d\x70\x78\x63\x68\x67\x33\x32\x5f\x72\x65\x73\x75\x6c\x74\x5f\x66\x61\
\x69\x6c\0\x63\x6d\x70\x78\x63\x68\x67\x33\x32\x5f\x72\x65\x73\x75\x6c\x74\x5f\
\x73\x75\x63\x63\x65\x65\x64\0\x78\x63\x68\x67\x36\x34\x5f\x76\x61\x6c\x75\x65\
\0\x78\x63\x68\x67\x36\x34\x5f\x72\x65\x73\x75\x6c\x74\0\x78\x63\x68\x67\x33\
\x32\x5f\x76\x61\x6c\x75\x65\0\x78\x63\x68\x67\x33\x32\x5f\x72\x65\x73\x75\x6c\
\x74\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\
\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x37\
\x30\x2e\x35\x2e\x31\x2e\x65\x6c\x39\x5f\x30\x2f\x6c\x69\x6e\x75\x78\x2d\x35\
\x2e\x31\x34\x2e\x30\x2d\x37\x30\x2e\x35\x2e\x31\x2e\x65\x6c\x39\x2e\x73\x33\
\x39\x30\x78\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\
\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\x2f\x70\x72\x6f\x67\x73\x2f\
\x61\x74\x6f\x6d\x69\x63\x73\x2e\x63\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\
\x4f\x47\x28\x61\x64\x64\x2c\x20\x69\x6e\x74\x20\x61\x29\0\x69\x6e\x74\x20\x42\
\x50\x46\x5f\x50\x52\x4f\x47\x28\x73\x75\x62\x2c\x20\x69\x6e\x74\x20\x61\x29\0\
\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x61\x6e\x64\x2c\x20\x69\
\x6e\x74\x20\x61\x29\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x6f\
\x72\x2c\x20\x69\x6e\x74\x20\x61\x29\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\
\x4f\x47\x28\x78\x6f\x72\x2c\x20\x69\x6e\x74\x20\x61\x29\0\x69\x6e\x74\x20\x42\
\x50\x46\x5f\x50\x52\x4f\x47\x28\x63\x6d\x70\x78\x63\x68\x67\x2c\x20\x69\x6e\
\x74\x20\x61\x29\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x78\x63\
\x68\x67\x2c\x20\x69\x6e\x74\x20\x61\x29\0\x2e\x64\x61\x74\x61\0\x2e\x62\x73\
\x73\0\x66\x65\x6e\x74\x72\x79\x2f\x62\x70\x66\x5f\x66\x65\x6e\x74\x72\x79\x5f\
\x74\x65\x73\x74\x31\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x09\xad\0\0\0\0\0\0\
\0\0\0\0\0\x02\0\0\0\x04\0\0\0\x9c\0\0\0\x01\0\0\x04\0\0\0\0\0\0\0\0\0\x61\x74\
\x6f\x6d\x69\x63\x73\x2e\x64\x61\x74\x61\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x3b\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\
\0\x01\0\0\0\0\0\0\0\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\x01\x10\0\0\0\
\0\0\0\x01\x10\0\0\0\0\0\0\x01\x10\0\0\0\0\0\0\x01\x10\0\0\0\0\0\0\x01\x10\0\0\
\0\0\0\0\x01\x10\0\0\0\0\0\0\x01\x10\0\0\0\0\0\0\x01\x10\0\0\0\0\0\0\x01\x10\0\
\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x01\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\
\0\x04\0\0\0\x94\0\0\0\x01\0\0\x04\0\0\0\0\0\0\0\0\0\x61\x74\x6f\x6d\x69\x63\
\x73\x2e\x62\x73\x73\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x3c\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\0\0\0\x02\xd8\0\0\x03\x53\0\0\x58\x05\0\0\0\
\x1a\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x61\x64\x64\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\0\0\0\
\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\
\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x62\x70\x66\x5f\x66\x65\x6e\x74\x72\x79\
\x5f\x74\x65\x73\x74\x31\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x06\0\0\0\0\0\0\x02\xd8\0\0\x03\x6c\0\0\xb8\x05\0\0\0\x1a\0\0\0\x02\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x73\x75\
\x62\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\
\0\0\0\0\0\x01\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x62\x70\x66\x5f\x66\x65\x6e\x74\x72\x79\x5f\x74\x65\x73\x74\x31\
\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x07\0\0\0\0\0\0\x02\xd8\
\0\0\x03\x85\0\x01\x10\x05\0\0\0\x1a\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x6e\x64\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\
\x10\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x62\
\x70\x66\x5f\x66\x65\x6e\x74\x72\x79\x5f\x74\x65\x73\x74\x31\0\0\xb7\0\0\0\0\0\
\0\0\x95\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\x02\xd8\0\0\x03\x9e\0\x01\
\x5c\x05\0\0\0\x1a\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x6f\x72\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x18\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x10\0\0\0\0\0\0\0\0\0\
\0\0\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x62\x70\x66\x5f\x66\x65\x6e\
\x74\x72\x79\x5f\x74\x65\x73\x74\x31\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x09\0\0\0\0\0\0\x02\xd8\0\0\x03\xb6\0\x01\xa4\x05\0\0\0\x1a\0\0\0\
\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x78\x6f\x72\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\
\x08\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x01\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x62\x70\x66\x5f\x66\x65\x6e\x74\x72\x79\x5f\x74\
\x65\x73\x74\x31\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0a\0\0\
\0\0\0\0\x02\xd8\0\0\x03\xcf\0\x01\xf0\x05\0\0\0\x1a\0\0\0\x02\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x6d\x70\
\x78\x63\x68\x67\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\x08\0\0\0\0\
\0\0\0\0\0\0\0\x01\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x01\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x62\x70\x66\x5f\x66\x65\x6e\x74\x72\x79\x5f\x74\x65\x73\x74\
\x31\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0b\0\0\0\0\0\0\x02\
\xd8\0\0\x03\xec\0\x02\x3c\x05\0\0\0\x1a\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x78\x63\x68\x67\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x01\0\
\0\0\x10\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x62\x70\x66\x5f\x66\x65\x6e\x74\x72\x79\x5f\x74\x65\x73\x74\x31\0";
	opts.insns_sz = 7328;
	opts.insns = (void *)"\
\xbf\x61\0\0\0\0\0\0\xbf\x1a\0\0\0\0\0\0\x07\x10\0\0\xff\xff\xfe\x78\xb7\x20\0\
\0\0\0\x01\x88\xb7\x30\0\0\0\0\0\0\x85\0\0\0\0\0\0\x71\x05\0\x01\x28\0\0\0\0\
\x61\x1a\xfe\x78\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\
\x7c\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\x80\0\0\0\0\
\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\x84\0\0\0\0\xd5\x10\0\
\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\x88\0\0\0\0\xd5\x10\0\x01\0\0\0\0\
\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\x8c\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\
\0\0\xa8\x61\x1a\xfe\x90\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\
\x1a\xfe\x94\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\x98\
\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\x9c\0\0\0\0\xd5\
\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\xa0\0\0\0\0\xd5\x10\0\x01\0\
\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\xa4\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\
\0\0\0\0\0\xa8\x61\x1a\xfe\xa8\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\
\xa8\x61\x1a\xfe\xac\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\
\xfe\xb0\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\xb4\0\0\
\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\xb8\0\0\0\0\xd5\x10\
\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\xbc\0\0\0\0\xd5\x10\0\x01\0\0\0\
\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\xc0\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\
\0\0\0\xa8\x61\x1a\xfe\xc4\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\
\x61\x1a\xfe\xc8\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\
\xcc\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\xd0\0\0\0\0\
\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\xd4\0\0\0\0\xd5\x10\0\
\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\xd8\0\0\0\0\xd5\x10\0\x01\0\0\0\0\
\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\xdc\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\
\0\0\xa8\x61\x1a\xfe\xe0\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\
\x1a\xfe\xe4\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\xe8\
\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\xec\0\0\0\0\xd5\
\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\xf0\0\0\0\0\xd5\x10\0\x01\0\
\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xfe\xf4\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\
\0\0\0\0\0\xa8\x61\x1a\xfe\xf8\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\
\xa8\x61\x1a\xfe\xfc\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\
\xff\0\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x04\0\0\0\
\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x08\0\0\0\0\xd5\x10\0\
\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x0c\0\0\0\0\xd5\x10\0\x01\0\0\0\0\
\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x10\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\
\0\0\xa8\x61\x1a\xff\x14\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\
\x1a\xff\x18\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x1c\
\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x20\0\0\0\0\xd5\
\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x24\0\0\0\0\xd5\x10\0\x01\0\
\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x28\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\
\0\0\0\0\0\xa8\x61\x1a\xff\x2c\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\
\xa8\x61\x1a\xff\x30\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\
\xff\x34\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x38\0\0\
\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x3c\0\0\0\0\xd5\x10\
\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x40\0\0\0\0\xd5\x10\0\x01\0\0\0\
\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x44\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\
\0\0\0\xa8\x61\x1a\xff\x48\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\
\x61\x1a\xff\x4c\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\
\x50\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x54\0\0\0\0\
\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x58\0\0\0\0\xd5\x10\0\
\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x5c\0\0\0\0\xd5\x10\0\x01\0\0\0\0\
\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x60\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\
\0\0\xa8\x61\x1a\xff\x64\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\
\x1a\xff\x68\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x6c\
\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x70\0\0\0\0\xd5\
\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x74\0\0\0\0\xd5\x10\0\x01\0\
\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x78\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\
\0\0\0\0\0\xa8\x61\x1a\xff\x7c\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\
\xa8\x61\x1a\xff\x80\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\
\xff\x84\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x88\0\0\
\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x8c\0\0\0\0\xd5\x10\
\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x90\0\0\0\0\xd5\x10\0\x01\0\0\0\
\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\x94\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\
\0\0\0\xa8\x61\x1a\xff\x98\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\
\x61\x1a\xff\x9c\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\
\xa0\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\xa4\0\0\0\0\
\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\xa8\0\0\0\0\xd5\x10\0\
\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\xac\0\0\0\0\xd5\x10\0\x01\0\0\0\0\
\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\xb0\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\
\0\0\xa8\x61\x1a\xff\xb4\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\
\x1a\xff\xb8\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\xbc\
\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\xc0\0\0\0\0\xd5\
\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\xc4\0\0\0\0\xd5\x10\0\x01\0\
\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\xc8\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\
\0\0\0\0\0\xa8\x61\x1a\xff\xcc\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\
\xa8\x61\x1a\xff\xd0\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\
\xff\xd4\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\xd8\0\0\
\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\xdc\0\0\0\0\xd5\x10\
\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\xe0\0\0\0\0\xd5\x10\0\x01\0\0\0\
\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\xe4\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\
\0\0\0\xa8\x61\x1a\xff\xe8\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\
\x61\x1a\xff\xec\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\
\xf0\0\0\0\0\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\xf4\0\0\0\0\
\xd5\x10\0\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\xf8\0\0\0\0\xd5\x10\0\
\x01\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\x1a\xff\xfc\0\0\0\0\xd5\x10\0\x01\0\0\0\0\
\x85\0\0\0\0\0\0\xa8\xbf\x07\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x61\x06\0\x08\0\0\0\
\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x09\xc5\x63\x10\0\0\0\0\0\0\x61\x06\0\x0c\0\
\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x09\xc1\x63\x10\0\0\0\0\0\0\x79\x06\0\
\x10\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x09\xb5\x7b\x10\0\0\0\0\0\0\x18\
\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x09\xad\x7b\
\x10\0\0\0\0\0\0\xb7\x10\0\0\0\0\0\x12\x18\x26\0\0\0\0\0\0\0\0\0\0\0\0\x09\xad\
\xb7\x30\0\0\0\0\0\x1c\x85\0\0\0\0\0\0\xa6\xbf\x70\0\0\0\0\0\0\xc5\x70\xfe\xc0\
\0\0\0\0\x63\xa7\xfe\x78\0\0\0\0\x61\x0a\xfe\x78\0\0\0\0\x18\x16\0\0\0\0\0\0\0\
\0\0\0\0\0\x09\xf9\x63\x10\0\0\0\0\0\0\x61\x06\0\x20\0\0\0\0\x15\0\0\x03\0\0\0\
\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x09\xd5\x63\x10\0\0\0\0\0\0\xb7\x10\0\0\0\0\
\0\0\x18\x26\0\0\0\0\0\0\0\0\0\0\0\0\x09\xc9\xb7\x30\0\0\0\0\0\x40\x85\0\0\0\0\
\0\0\xa6\xbf\x70\0\0\0\0\0\0\xc5\x70\xfe\xaf\0\0\0\0\x63\xa7\xfe\x7c\0\0\0\0\
\x79\x36\0\x18\0\0\0\0\x15\x30\0\x04\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\
\x0a\x09\xb7\x20\0\0\0\0\0\x9c\x85\0\0\0\0\0\0\x94\x61\x0a\xfe\x7c\0\0\0\0\x18\
\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0a\xa9\x63\x10\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\
\0\0\0\0\0\x0a\xa5\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0a\xb1\x7b\x10\0\0\0\0\0\0\
\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0a\x09\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0a\
\xb9\x7b\x10\0\0\0\0\0\0\xb7\x10\0\0\0\0\0\x02\x18\x26\0\0\0\0\0\0\0\0\0\0\0\0\
\x0a\xa9\xb7\x30\0\0\0\0\0\x20\x85\0\0\0\0\0\0\xa6\xbf\x70\0\0\0\0\0\0\xc5\x70\
\xfe\x93\0\0\0\0\x61\x0a\xfe\x78\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0a\
\xf9\x63\x10\0\0\0\0\0\0\x61\x06\0\x30\0\0\0\0\x15\0\0\x03\0\0\0\0\x18\x16\0\0\
\0\0\0\0\0\0\0\0\0\0\x0a\xd5\x63\x10\0\0\0\0\0\0\xb7\x10\0\0\0\0\0\0\x18\x26\0\
\0\0\0\0\0\0\0\0\0\0\0\x0a\xc9\xb7\x30\0\0\0\0\0\x40\x85\0\0\0\0\0\0\xa6\xbf\
\x70\0\0\0\0\0\0\xc5\x70\xfe\x83\0\0\0\0\x63\xa7\xfe\x80\0\0\0\0\x79\x36\0\x28\
\0\0\0\0\x15\x30\0\x04\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0b\x09\xb7\x20\
\0\0\0\0\0\x94\x85\0\0\0\0\0\0\x94\x61\x0a\xfe\x80\0\0\0\0\x18\x16\0\0\0\0\0\0\
\0\0\0\0\0\0\x0b\xa1\x63\x10\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0b\
\x9d\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0b\xa9\x7b\x10\0\0\0\0\0\0\x18\x06\0\0\0\
\0\0\0\0\0\0\0\0\0\x0b\x09\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0b\xb1\x7b\x10\0\0\
\0\0\0\0\xb7\x10\0\0\0\0\0\x02\x18\x26\0\0\0\0\0\0\0\0\0\0\0\0\x0b\xa1\xb7\x30\
\0\0\0\0\0\x20\x85\0\0\0\0\0\0\xa6\xbf\x70\0\0\0\0\0\0\xc5\x70\xfe\x67\0\0\0\0\
\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0b\xc1\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0b\
\xfa\x7b\x10\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0b\xc2\x18\x16\0\0\0\
\0\0\0\0\0\0\0\0\0\x0b\xf2\x7b\x10\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\
\x0b\xd2\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0c\x3a\x7b\x10\0\0\0\0\0\0\x18\x06\0\
\0\0\0\0\0\0\0\0\0\0\0\x0b\xda\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0c\x4a\x7b\x10\
\0\0\0\0\0\0\xbf\x0a\0\0\0\0\0\0\x07\0\0\0\xff\xff\xfe\x7c\x18\x16\0\0\0\0\0\0\
\0\0\0\0\0\0\x0c\x62\x7b\x10\0\0\0\0\0\0\x61\x06\0\x08\0\0\0\0\x18\x16\0\0\0\0\
\0\0\0\0\0\0\0\0\x0c\x02\x63\x10\0\0\0\0\0\0\x61\x06\0\x0c\0\0\0\0\x18\x16\0\0\
\0\0\0\0\0\0\0\0\0\0\x0c\x06\x63\x10\0\0\0\0\0\0\x79\x06\0\x10\0\0\0\0\x18\x16\
\0\0\0\0\0\0\0\0\0\0\0\0\x0c\x0a\x7b\x10\0\0\0\0\0\0\x61\x0a\xfe\x78\0\0\0\0\
\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0c\x32\x63\x10\0\0\0\0\0\0\x18\x16\0\0\0\0\0\
\0\0\0\0\0\0\0\x0c\x6a\xb7\x20\0\0\0\0\0\x11\xb7\x30\0\0\0\0\0\x0c\xb7\x40\0\0\
\0\0\0\0\x85\0\0\0\0\0\0\xa7\xbf\x70\0\0\0\0\0\0\xc5\x70\xfe\x36\0\0\0\0\x18\
\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0b\xea\x63\x07\0\x6c\0\0\0\0\x77\x70\0\0\0\0\0\
\x20\x63\x07\0\x70\0\0\0\0\xb7\x10\0\0\0\0\0\x05\x18\x26\0\0\0\0\0\0\0\0\0\0\0\
\0\x0b\xea\xb7\x30\0\0\0\0\0\x80\x85\0\0\0\0\0\0\xa6\xbf\x70\0\0\0\0\0\0\x18\
\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0c\x5a\x61\x10\0\0\0\0\0\0\xd5\x10\0\x02\0\0\0\0\
\xbf\x91\0\0\0\0\0\0\x85\0\0\0\0\0\0\xa8\xc5\x70\xfe\x24\0\0\0\0\x63\xa7\xff\
\x7c\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0c\x7b\x18\x16\0\0\0\0\0\0\0\0\0\
\0\0\0\x0c\xb4\x7b\x10\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0c\x7c\x18\
\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0c\xac\x7b\x10\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\
\0\0\0\0\0\x0c\x8c\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0c\xf4\x7b\x10\0\0\0\0\0\0\
\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0c\x94\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0d\
\x04\x7b\x10\0\0\0\0\0\0\xbf\x0a\0\0\0\0\0\0\x07\0\0\0\xff\xff\xfe\x7c\x18\x16\
\0\0\0\0\0\0\0\0\0\0\0\0\x0d\x1c\x7b\x10\0\0\0\0\0\0\x61\x06\0\x08\0\0\0\0\x18\
\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0c\xbc\x63\x10\0\0\0\0\0\0\x61\x06\0\x0c\0\0\0\0\
\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0c\xc0\x63\x10\0\0\0\0\0\0\x79\x06\0\x10\0\0\
\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0c\xc4\x7b\x10\0\0\0\0\0\0\x61\x0a\xfe\
\x78\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0c\xec\x63\x10\0\0\0\0\0\0\x18\
\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0d\x24\xb7\x20\0\0\0\0\0\x11\xb7\x30\0\0\0\0\0\
\x0c\xb7\x40\0\0\0\0\0\0\x85\0\0\0\0\0\0\xa7\xbf\x70\0\0\0\0\0\0\xc5\x70\xfd\
\xf2\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0c\xa4\x63\x07\0\x6c\0\0\0\0\x77\
\x70\0\0\0\0\0\x20\x63\x07\0\x70\0\0\0\0\xb7\x10\0\0\0\0\0\x05\x18\x26\0\0\0\0\
\0\0\0\0\0\0\0\0\x0c\xa4\xb7\x30\0\0\0\0\0\x80\x85\0\0\0\0\0\0\xa6\xbf\x70\0\0\
\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0d\x14\x61\x10\0\0\0\0\0\0\xd5\x10\0\
\x02\0\0\0\0\xbf\x91\0\0\0\0\0\0\x85\0\0\0\0\0\0\xa8\xc5\x70\xfd\xe0\0\0\0\0\
\x63\xa7\xff\x80\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0d\x35\x18\x16\0\0\0\
\0\0\0\0\0\0\0\0\0\x0d\x6e\x7b\x10\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\
\x0d\x36\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0d\x66\x7b\x10\0\0\0\0\0\0\x18\x06\0\
\0\0\0\0\0\0\0\0\0\0\0\x0d\x46\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0d\xae\x7b\x10\
\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0d\x4e\x18\x16\0\0\0\0\0\0\0\0\0\
\0\0\0\x0d\xbe\x7b\x10\0\0\0\0\0\0\xbf\x0a\0\0\0\0\0\0\x07\0\0\0\xff\xff\xfe\
\x7c\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0d\xd6\x7b\x10\0\0\0\0\0\0\x61\x06\0\x08\
\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0d\x76\x63\x10\0\0\0\0\0\0\x61\x06\0\
\x0c\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0d\x7a\x63\x10\0\0\0\0\0\0\x79\
\x06\0\x10\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0d\x7e\x7b\x10\0\0\0\0\0\0\
\x61\x0a\xfe\x78\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0d\xa6\x63\x10\0\0\0\
\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0d\xde\xb7\x20\0\0\0\0\0\x11\xb7\x30\0\
\0\0\0\0\x0c\xb7\x40\0\0\0\0\0\0\x85\0\0\0\0\0\0\xa7\xbf\x70\0\0\0\0\0\0\xc5\
\x70\xfd\xae\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0d\x5e\x63\x07\0\x6c\0\0\
\0\0\x77\x70\0\0\0\0\0\x20\x63\x07\0\x70\0\0\0\0\xb7\x10\0\0\0\0\0\x05\x18\x26\
\0\0\0\0\0\0\0\0\0\0\0\0\x0d\x5e\xb7\x30\0\0\0\0\0\x80\x85\0\0\0\0\0\0\xa6\xbf\
\x70\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0d\xce\x61\x10\0\0\0\0\0\0\
\xd5\x10\0\x02\0\0\0\0\xbf\x91\0\0\0\0\0\0\x85\0\0\0\0\0\0\xa8\xc5\x70\xfd\x9c\
\0\0\0\0\x63\xa7\xff\x84\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0d\xef\x18\
\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0e\x28\x7b\x10\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\
\0\0\0\0\0\x0d\xf0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0e\x20\x7b\x10\0\0\0\0\0\0\
\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0e\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0e\x68\
\x7b\x10\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0e\x08\x18\x16\0\0\0\0\0\
\0\0\0\0\0\0\0\x0e\x78\x7b\x10\0\0\0\0\0\0\xbf\x0a\0\0\0\0\0\0\x07\0\0\0\xff\
\xff\xfe\x7c\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0e\x90\x7b\x10\0\0\0\0\0\0\x61\
\x06\0\x08\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0e\x30\x63\x10\0\0\0\0\0\0\
\x61\x06\0\x0c\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0e\x34\x63\x10\0\0\0\0\
\0\0\x79\x06\0\x10\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0e\x38\x7b\x10\0\0\
\0\0\0\0\x61\x0a\xfe\x78\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0e\x60\x63\
\x10\0\0\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0e\x98\xb7\x20\0\0\0\0\0\x11\
\xb7\x30\0\0\0\0\0\x0c\xb7\x40\0\0\0\0\0\0\x85\0\0\0\0\0\0\xa7\xbf\x70\0\0\0\0\
\0\0\xc5\x70\xfd\x6a\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0e\x18\x63\x07\0\
\x6c\0\0\0\0\x77\x70\0\0\0\0\0\x20\x63\x07\0\x70\0\0\0\0\xb7\x10\0\0\0\0\0\x05\
\x18\x26\0\0\0\0\0\0\0\0\0\0\0\0\x0e\x18\xb7\x30\0\0\0\0\0\x80\x85\0\0\0\0\0\0\
\xa6\xbf\x70\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0e\x88\x61\x10\0\0\0\
\0\0\0\xd5\x10\0\x02\0\0\0\0\xbf\x91\0\0\0\0\0\0\x85\0\0\0\0\0\0\xa8\xc5\x70\
\xfd\x58\0\0\0\0\x63\xa7\xff\x88\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0e\
\xa9\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0e\xe2\x7b\x10\0\0\0\0\0\0\x18\x06\0\0\0\
\0\0\0\0\0\0\0\0\0\x0e\xaa\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0e\xda\x7b\x10\0\0\
\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0e\xba\x18\x16\0\0\0\0\0\0\0\0\0\0\0\
\0\x0f\x22\x7b\x10\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0e\xc2\x18\x16\
\0\0\0\0\0\0\0\0\0\0\0\0\x0f\x32\x7b\x10\0\0\0\0\0\0\xbf\x0a\0\0\0\0\0\0\x07\0\
\0\0\xff\xff\xfe\x7c\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0f\x4a\x7b\x10\0\0\0\0\0\
\0\x61\x06\0\x08\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0e\xea\x63\x10\0\0\0\
\0\0\0\x61\x06\0\x0c\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0e\xee\x63\x10\0\
\0\0\0\0\0\x79\x06\0\x10\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0e\xf2\x7b\
\x10\0\0\0\0\0\0\x61\x0a\xfe\x78\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0f\
\x1a\x63\x10\0\0\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0f\x52\xb7\x20\0\0\0\
\0\0\x11\xb7\x30\0\0\0\0\0\x0c\xb7\x40\0\0\0\0\0\0\x85\0\0\0\0\0\0\xa7\xbf\x70\
\0\0\0\0\0\0\xc5\x70\xfd\x26\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0e\xd2\
\x63\x07\0\x6c\0\0\0\0\x77\x70\0\0\0\0\0\x20\x63\x07\0\x70\0\0\0\0\xb7\x10\0\0\
\0\0\0\x05\x18\x26\0\0\0\0\0\0\0\0\0\0\0\0\x0e\xd2\xb7\x30\0\0\0\0\0\x80\x85\0\
\0\0\0\0\0\xa6\xbf\x70\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0f\x42\x61\
\x10\0\0\0\0\0\0\xd5\x10\0\x02\0\0\0\0\xbf\x91\0\0\0\0\0\0\x85\0\0\0\0\0\0\xa8\
\xc5\x70\xfd\x14\0\0\0\0\x63\xa7\xff\x8c\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\
\0\x0f\x63\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0f\x9c\x7b\x10\0\0\0\0\0\0\x18\x06\
\0\0\0\0\0\0\0\0\0\0\0\0\x0f\x64\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0f\x94\x7b\
\x10\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0f\x74\x18\x16\0\0\0\0\0\0\0\
\0\0\0\0\0\x0f\xdc\x7b\x10\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x0f\x7c\
\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0f\xec\x7b\x10\0\0\0\0\0\0\xbf\x0a\0\0\0\0\0\
\0\x07\0\0\0\xff\xff\xfe\x7c\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x10\x04\x7b\x10\0\
\0\0\0\0\0\x61\x06\0\x08\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0f\xa4\x63\
\x10\0\0\0\0\0\0\x61\x06\0\x0c\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0f\xa8\
\x63\x10\0\0\0\0\0\0\x79\x06\0\x10\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x0f\
\xac\x7b\x10\0\0\0\0\0\0\x61\x0a\xfe\x78\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\
\0\x0f\xd4\x63\x10\0\0\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x10\x0c\xb7\x20\
\0\0\0\0\0\x11\xb7\x30\0\0\0\0\0\x0c\xb7\x40\0\0\0\0\0\0\x85\0\0\0\0\0\0\xa7\
\xbf\x70\0\0\0\0\0\0\xc5\x70\xfc\xe2\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\
\x0f\x8c\x63\x07\0\x6c\0\0\0\0\x77\x70\0\0\0\0\0\x20\x63\x07\0\x70\0\0\0\0\xb7\
\x10\0\0\0\0\0\x05\x18\x26\0\0\0\0\0\0\0\0\0\0\0\0\x0f\x8c\xb7\x30\0\0\0\0\0\
\x80\x85\0\0\0\0\0\0\xa6\xbf\x70\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\
\x0f\xfc\x61\x10\0\0\0\0\0\0\xd5\x10\0\x02\0\0\0\0\xbf\x91\0\0\0\0\0\0\x85\0\0\
\0\0\0\0\xa8\xc5\x70\xfc\xd0\0\0\0\0\x63\xa7\xff\x90\0\0\0\0\x18\x06\0\0\0\0\0\
\0\0\0\0\0\0\0\x10\x1d\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x10\x56\x7b\x10\0\0\0\0\
\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x10\x1e\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\
\x10\x4e\x7b\x10\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\x10\x2e\x18\x16\0\
\0\0\0\0\0\0\0\0\0\0\0\x10\x96\x7b\x10\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\
\0\0\x10\x36\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x10\xa6\x7b\x10\0\0\0\0\0\0\xbf\
\x0a\0\0\0\0\0\0\x07\0\0\0\xff\xff\xfe\x7c\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x10\
\xbe\x7b\x10\0\0\0\0\0\0\x61\x06\0\x08\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\
\x10\x5e\x63\x10\0\0\0\0\0\0\x61\x06\0\x0c\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\
\0\0\x10\x62\x63\x10\0\0\0\0\0\0\x79\x06\0\x10\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\
\0\0\0\0\x10\x66\x7b\x10\0\0\0\0\0\0\x61\x0a\xfe\x78\0\0\0\0\x18\x16\0\0\0\0\0\
\0\0\0\0\0\0\0\x10\x8e\x63\x10\0\0\0\0\0\0\x18\x16\0\0\0\0\0\0\0\0\0\0\0\0\x10\
\xc6\xb7\x20\0\0\0\0\0\x11\xb7\x30\0\0\0\0\0\x0c\xb7\x40\0\0\0\0\0\0\x85\0\0\0\
\0\0\0\xa7\xbf\x70\0\0\0\0\0\0\xc5\x70\xfc\x9e\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\
\0\0\0\0\x10\x46\x63\x07\0\x6c\0\0\0\0\x77\x70\0\0\0\0\0\x20\x63\x07\0\x70\0\0\
\0\0\xb7\x10\0\0\0\0\0\x05\x18\x26\0\0\0\0\0\0\0\0\0\0\0\0\x10\x46\xb7\x30\0\0\
\0\0\0\x80\x85\0\0\0\0\0\0\xa6\xbf\x70\0\0\0\0\0\0\x18\x06\0\0\0\0\0\0\0\0\0\0\
\0\0\x10\xb6\x61\x10\0\0\0\0\0\0\xd5\x10\0\x02\0\0\0\0\xbf\x91\0\0\0\0\0\0\x85\
\0\0\0\0\0\0\xa8\xc5\x70\xfc\x8c\0\0\0\0\x63\xa7\xff\x94\0\0\0\0\x61\x1a\xfe\
\x78\0\0\0\0\xd5\x10\0\x02\0\0\0\0\xbf\x91\0\0\0\0\0\0\x85\0\0\0\0\0\0\xa8\x61\
\x0a\xff\x7c\0\0\0\0\x63\x60\0\x38\0\0\0\0\x61\x0a\xff\x80\0\0\0\0\x63\x60\0\
\x3c\0\0\0\0\x61\x0a\xff\x84\0\0\0\0\x63\x60\0\x40\0\0\0\0\x61\x0a\xff\x88\0\0\
\0\0\x63\x60\0\x44\0\0\0\0\x61\x0a\xff\x8c\0\0\0\0\x63\x60\0\x48\0\0\0\0\x61\
\x0a\xff\x90\0\0\0\0\x63\x60\0\x4c\0\0\0\0\x61\x0a\xff\x94\0\0\0\0\x63\x60\0\
\x50\0\0\0\0\x61\x0a\xfe\x7c\0\0\0\0\x63\x60\0\x18\0\0\0\0\x61\x0a\xfe\x80\0\0\
\0\0\x63\x60\0\x28\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0";
	err = bpf_load_and_run(&opts);
	if (err < 0)
		return err;
	skel->data =
		mmap(skel->data, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED,
			skel->maps.data.map_fd, 0);
	skel->bss =
		mmap(skel->bss, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED,
			skel->maps.bss.map_fd, 0);
	return 0;
}

static inline struct atomics *
atomics__open_and_load(void)
{
	struct atomics *skel;

	skel = atomics__open();
	if (!skel)
		return NULL;
	if (atomics__load(skel)) {
		atomics__destroy(skel);
		return NULL;
	}
	return skel;
}

#endif /* __ATOMICS_SKEL_H__ */
